Module control

Module control 

Stable control-plane facade.

This module is the canonical SDK surface for runtime integrations, including client/server types and protocol contracts.

Modules

auth
error
Error types for admin
metrics
System metrics collection using pwrzv
nonce_auth
Nonce-auth integration module
realm
service

Structs

AdminApiService
AdminApiService — canonical business-logic layer for node administration.
AuthService
在进入业务实现前统一做 NonceCredential 校验的包装服务
ConfigFileContent
Config file content with path.
ControlServiceClient
ControlServiceServer
CreateRealmRequest
CreateRealmResponse
DeleteConfigOverrideRequest
DeleteConfigOverrideResponse
DeleteRealmRequest
DeleteRealmResponse
Directive
GetConfigRequest
GetConfigResponse
GetNodeInfoRequest
GetNodeInfoResponse
GetRealmRequest
GetRealmResponse
HealthCheckRequest
HealthCheckResponse
HealthInfo
Health check response.
KeyInfo
Key info (shared by Signer and AIS).
KsCleanupResult
Signer cleanup result.
KsKeysResult
Signer keys query result.
ListConfigOverridesRequest
ListConfigOverridesResponse
ListRealmsRequest
ListRealmsResponse
NodeAdminServiceClient
NodeAdminServiceServer
NonceCredential
NonceCredential is used for authentication in all RPC requests Compatible with nonce-auth library’s NonceCredential structure
PlatformDetail
Platform detail with resolved config fields.
ProtoConfigOverrideEntry
RealmInfo
RealmSecretRotationResult
Realm secret 轮转结果(明文 secret 仅返回一次)。
RegisterNodeRequest
RegisterNodeResponse
ReportRequest
ReportResponse
ServiceAdvertisement
ServiceDetail
Service detail with resolved config fields.
ServiceStatus
SetConfigOverrideRequest
SetConfigOverrideResponse
ShutdownRequest
ShutdownResponse
SystemMetrics
UpdateConfigRequest
UpdateConfigResponse
UpdateRealmRequest
UpdateRealmResponse

Enums

AdminError
ConfigType
DirectiveType
ResourceType
ServiceAdvertisementStatus

Traits

ControlService
Generated trait containing gRPC methods that should be implemented for use with ControlServiceServer.
CredentialPayload
请求体需要提供认证载荷与凭证
NodeAdminService
Generated trait containing gRPC methods that should be implemented for use with NodeAdminServiceServer.

Functions

realm_to_proto
Convert a Realm record into proto RealmInfo

Type Aliases

AdminResult