#[repr(i32)]pub enum DirectiveType {
Unspecified = 0,
AdjustInterval = 1,
RequestFullReport = 2,
GracefulShutdown = 3,
}Variants
Unspecified = 0
AdjustInterval = 1
Change report frequency
RequestFullReport = 2
Request detailed metrics
GracefulShutdown = 3
Shutdown signal
Implementations
Sourceimpl DirectiveType
impl DirectiveType
Sourceimpl DirectiveType
impl DirectiveType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<DirectiveType>
pub fn from_str_name(value: &str) -> Option<DirectiveType>
Creates an enum from field names used in the ProtoBuf definition.