pub struct Directive {
pub type: i32,
pub payload: Option<String>,
}Fields
type: i32Directive type
payload: Option<String>Optional payload data
Implementations
Sourceimpl Directive
impl Directive
Sourcepub fn type(&self) -> DirectiveType
pub fn type(&self) -> DirectiveType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: DirectiveType)
pub fn set_type(&mut self, value: DirectiveType)
Sets type to the provided enum value.