pub struct ServiceAdvertisement {
pub name: String,
pub type: i32,
pub domain_name: String,
pub port_info: String,
pub status: i32,
pub description: Option<String>,
pub url: Option<String>,
pub tags: Vec<String>,
}Fields
name: StringService identifier
type: i32Service type for routing
domain_name: StringDomain (or host) used for access
port_info: StringPort or port range description
status: i32Current advertised status
description: Option<String>Optional description
url: Option<String>External URL if reachable
Optional tags for filtering
Implementations
Sourceimpl ServiceAdvertisement
impl ServiceAdvertisement
Sourcepub fn type(&self) -> ResourceType
pub fn type(&self) -> ResourceType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ResourceType)
pub fn set_type(&mut self, value: ResourceType)
Sets type to the provided enum value.
Sourcepub fn status(&self) -> ServiceAdvertisementStatus
pub fn status(&self) -> ServiceAdvertisementStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ServiceAdvertisementStatus)
pub fn set_status(&mut self, value: ServiceAdvertisementStatus)
Sets status to the provided enum value.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.