pub struct ServiceStatus {
pub name: String,
pub type: i32,
pub is_healthy: bool,
pub active_connections: u32,
pub total_requests: u64,
pub failed_requests: u64,
pub average_latency_ms: f64,
pub url: Option<String>,
pub port: Option<u32>,
pub domain: Option<String>,
}Fields
name: StringService identifier
type: i32Service type (routing basis)
is_healthy: boolHealth status (scheduling core)
active_connections: u32Connection count (load assessment)
total_requests: u64Total requests (traffic monitoring)
failed_requests: u64Failed requests (quality monitoring)
average_latency_ms: f64Latency (performance monitoring)
url: Option<String>Service URL (external access)
port: Option<u32>Service port (internal services may not need)
domain: Option<String>Service domain (not needed for internal IP access)
Implementations
Sourceimpl ServiceStatus
impl ServiceStatus
Sourcepub fn type(&self) -> ResourceType
pub fn type(&self) -> ResourceType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ResourceType)
pub fn set_type(&mut self, value: ResourceType)
Sets type to the provided enum value.