pub struct UpdateRealmRequest {
pub realm_id: u32,
pub name: Option<String>,
pub enabled: Option<bool>,
pub credential: NonceCredential,
pub status: Option<String>,
pub expires_at: Option<u64>,
pub secret_current_hash: Option<String>,
pub secret_previous_hash: Option<String>,
pub secret_previous_valid_until: Option<u64>,
}Fields
realm_id: u32Realm identifier
name: Option<String>New name (optional update)
enabled: Option<bool>New enabled status (optional update)
credential: NonceCredentialAuthentication credential
status: Option<String>Active / Inactive / Suspended
expires_at: Option<u64>Expiration timestamp (Unix timestamp)
secret_current_hash: Option<String>Current realm secret hash from superv
secret_previous_hash: Option<String>Previous realm secret hash during rotation
secret_previous_valid_until: Option<u64>Previous secret grace-window deadline
Implementations
Sourceimpl UpdateRealmRequest
impl UpdateRealmRequest
Sourcepub fn enabled(&self) -> bool
pub fn enabled(&self) -> bool
Returns the value of enabled, or the default value if enabled is unset.
Sourcepub fn status(&self) -> &str
pub fn status(&self) -> &str
Returns the value of status, or the default value if status is unset.
Sourcepub fn expires_at(&self) -> u64
pub fn expires_at(&self) -> u64
Returns the value of expires_at, or the default value if expires_at is unset.
Sourcepub fn secret_current_hash(&self) -> &str
pub fn secret_current_hash(&self) -> &str
Returns the value of secret_current_hash, or the default value if secret_current_hash is unset.
Sourcepub fn secret_previous_hash(&self) -> &str
pub fn secret_previous_hash(&self) -> &str
Returns the value of secret_previous_hash, or the default value if secret_previous_hash is unset.
Sourcepub fn secret_previous_valid_until(&self) -> u64
pub fn secret_previous_valid_until(&self) -> u64
Returns the value of secret_previous_valid_until, or the default value if secret_previous_valid_until is unset.