Stable control-plane facade.
This module is the canonical SDK surface for runtime integrations, including client/server types and protocol contracts.
Modules
- auth
- error
- Error types for admin
- metrics
- System metrics collection using pwrzv
- nonce_
auth - Nonce-auth integration module
- realm
- service
Structs
- Admin
ApiService - AdminApiService — canonical business-logic layer for node administration.
- Auth
Service - 在进入业务实现前统一做 NonceCredential 校验的包装服务
- Config
File Content - Config file content with path.
- Control
Service Client - Control
Service Server - Create
Realm Request - Create
Realm Response - Delete
Config Override Request - Delete
Config Override Response - Delete
Realm Request - Delete
Realm Response - Directive
- GetConfig
Request - GetConfig
Response - GetNode
Info Request - GetNode
Info Response - GetRealm
Request - GetRealm
Response - Health
Check Request - Health
Check Response - Health
Info - Health check response.
- KeyInfo
- Key info (shared by Signer and AIS).
- KsCleanup
Result - Signer cleanup result.
- KsKeys
Result - Signer keys query result.
- List
Config Overrides Request - List
Config Overrides Response - List
Realms Request - List
Realms Response - Node
Admin Service Client - Node
Admin Service Server - Nonce
Credential - NonceCredential is used for authentication in all RPC requests Compatible with nonce-auth library’s NonceCredential structure
- Platform
Detail - Platform detail with resolved config fields.
- Proto
Config Override Entry - Realm
Info - Realm
Secret Rotation Result - Realm secret 轮转结果(明文 secret 仅返回一次)。
- Register
Node Request - Register
Node Response - Report
Request - Report
Response - Service
Advertisement - Service
Detail - Service detail with resolved config fields.
- Service
Status - SetConfig
Override Request - SetConfig
Override Response - Shutdown
Request - Shutdown
Response - System
Metrics - Update
Config Request - Update
Config Response - Update
Realm Request - Update
Realm Response
Enums
Traits
- Control
Service - Generated trait containing gRPC methods that should be implemented for use with ControlServiceServer.
- Credential
Payload - 请求体需要提供认证载荷与凭证
- Node
Admin Service - Generated trait containing gRPC methods that should be implemented for use with NodeAdminServiceServer.
Functions
- realm_
to_ proto - Convert a Realm record into proto RealmInfo